@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2012 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2013 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,9 +24,8 @@
 extern "C"{
 #include <libavformat/avformat.h>
 #include <libavcodec/avcodec.h>
-#if (LIBAVUTIL_VERSION_INT >= ((51<<16)+(32<<8)+0))
 #include <libavutil/dict.h>
-#endif
+#include <libavutil/avutil.h>
 }
 
 #include "ffmpegmetadatamodel.h"
@@ -37,6 +36,13 @@ extern "C"{
 
 // DecoderFFmpegFactory
 
+DecoderFFmpegFactory::DecoderFFmpegFactory()
+{
+    avcodec_register_all();
+    avformat_network_init();
+    av_register_all();
+}
+
 bool DecoderFFmpegFactory::supports(const QString &source) const
 {
     foreach(QString filter, properties().filters)
@@ -50,7 +56,6 @@ bool DecoderFFmpegFactory::supports(const QString &source) const
 
 bool DecoderFFmpegFactory::canDecode(QIODevice *i) const
 {
-    av_register_all();
     QStringList filters = properties().filters;
 
     AVProbeData  pd;
@@ -63,7 +68,6 @@ bool DecoderFFmpegFactory::canDecode(QIODevice *i) const
     AVInputFormat *fmt = av_probe_input_format(&pd, 1);
     if(!fmt)
     {
-        qWarning("DecoderFFmpegFactory: usupported format");
         return false;
     }
     if(filters.contains("*.wma") && !memcmp(fmt->name, "asf", 3))
@@ -87,8 +91,36 @@ const DecoderProperties DecoderFFmpegFactory::properties() const
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     QStringList filters;
-    filters << "*.wma" << "*.ape";
+    filters << "*.wma" << "*.ape" << "*.tta" << "*.m4a" << "*.ra" << "*.shn" << "*.vqf" << "*.ac3";
     filters = settings.value("FFMPEG/filters", filters).toStringList();
+
+    //removed unsupported filters
+    if(!avcodec_find_decoder(CODEC_ID_WMAV1))
+        filters.removeAll("*.wma");
+    if(!avcodec_find_decoder(CODEC_ID_APE))
+        filters.removeAll("*.ape");
+    if(!avcodec_find_decoder(CODEC_ID_TTA))
+        filters.removeAll("*.tta");
+    if(!avcodec_find_decoder(CODEC_ID_AAC))
+        filters.removeAll("*.aac");
+    if(!avcodec_find_decoder(CODEC_ID_MP3))
+        filters.removeAll("*.mp3");
+    if(!avcodec_find_decoder(CODEC_ID_AAC) && !avcodec_find_decoder(CODEC_ID_ALAC))
+        filters.removeAll("*.m4a");
+    if(!avcodec_find_decoder(CODEC_ID_RA_288))
+        filters.removeAll("*.ra");
+    if(!avcodec_find_decoder(CODEC_ID_SHORTEN))
+        filters.removeAll("*.shn");
+    if(!avcodec_find_decoder(CODEC_ID_EAC3))
+        filters.removeAll("*.ac3");
+    if(!avcodec_find_decoder(CODEC_ID_DTS))
+        filters.removeAll("*.dts");
+    if(!avcodec_find_decoder(CODEC_ID_TRUEHD))
+        filters.removeAll("*.mka");
+    if(!avcodec_find_decoder(CODEC_ID_TWINVQ))
+        filters.removeAll("*.vqf");
+
+
     DecoderProperties properties;
     properties.name = tr("FFmpeg Plugin");
     properties.filters = filters;
@@ -128,11 +160,7 @@ Decoder *DecoderFFmpegFactory::create(const QString &path, QIODevice *input)
 
 QList<FileInfo *> DecoderFFmpegFactory::createPlayList(const QString &fileName, bool useMetaData)
 {
-#if (LIBAVCODEC_VERSION_INT >= ((53<<16)+(42<<8)+4))
     QList <FileInfo*> list;
-    avcodec_register_all();
-    avformat_network_init();
-    av_register_all();
     AVFormatContext *in = 0;
 
     if (avformat_open_input(&in,fileName.toLocal8Bit().constData(), 0, 0) < 0)
@@ -182,61 +210,6 @@ QList<FileInfo *> DecoderFFmpegFactory::createPlayList(const QString &fileName,
     }
     info->setLength(in->duration/AV_TIME_BASE);
     avformat_close_input(&in);
-#else
-    QList <FileInfo*> list;
-    avcodec_init();
-    avcodec_register_all();
-    av_register_all();
-    AVFormatContext *in = 0;
-
-    if (av_open_input_file(&in, fileName.toLocal8Bit(), 0, 0, 0) < 0)
-    {
-        qDebug("DecoderFFmpegFactory: unable to open file");
-        return list;
-    }
-    FileInfo *info = new FileInfo(fileName);
-    av_find_stream_info(in);
-
-    if (useMetaData)
-    {
-        AVMetadataTag *album = av_metadata_get(in->metadata,"album",0,0);
-        if(!album)
-            album = av_metadata_get(in->metadata,"WM/AlbumTitle",0,0);
-        AVMetadataTag *artist = av_metadata_get(in->metadata,"artist",0,0);
-        if(!artist)
-            artist = av_metadata_get(in->metadata,"author",0,0);
-        AVMetadataTag *comment = av_metadata_get(in->metadata,"comment",0,0);
-        AVMetadataTag *genre = av_metadata_get(in->metadata,"genre",0,0);
-        AVMetadataTag *title = av_metadata_get(in->metadata,"title",0,0);
-        AVMetadataTag *year = av_metadata_get(in->metadata,"WM/Year",0,0);
-        if(!year)
-            year = av_metadata_get(in->metadata,"year",0,0);
-        if(!year)
-            year = av_metadata_get(in->metadata,"date",0,0);
-        AVMetadataTag *track = av_metadata_get(in->metadata,"track",0,0);
-        if(!track)
-            track = av_metadata_get(in->metadata,"WM/Track",0,0);
-        if(!track)
-            track = av_metadata_get(in->metadata,"WM/TrackNumber",0,0);
-
-        if(album)
-            info->setMetaData(Qmmp::ALBUM, QString::fromUtf8(album->value).trimmed());
-        if(artist)
-            info->setMetaData(Qmmp::ARTIST, QString::fromUtf8(artist->value).trimmed());
-        if(comment)
-            info->setMetaData(Qmmp::COMMENT, QString::fromUtf8(comment->value).trimmed());
-        if(genre)
-            info->setMetaData(Qmmp::GENRE, QString::fromUtf8(genre->value).trimmed());
-        if(title)
-            info->setMetaData(Qmmp::TITLE, QString::fromUtf8(title->value).trimmed());
-        if(year)
-            info->setMetaData(Qmmp::YEAR, year->value);
-        if(track)
-            info->setMetaData(Qmmp::TRACK, track->value);
-    }
-    info->setLength(in->duration/AV_TIME_BASE);
-    av_close_input_file(in);
-#endif
     list << info;
     return list;
 }
@@ -255,15 +228,20 @@ void DecoderFFmpegFactory::showSettings(QWidget *parent)
 void DecoderFFmpegFactory::showAbout(QWidget *parent)
 {
     QMessageBox::about (parent, tr("About FFmpeg Audio Plugin"),
-
                         tr("Qmmp FFmpeg Audio Plugin")+"\n"+
-                        QString(tr("Compiled against libavformat-%1.%2.%3 and libavcodec-%4.%5.%6"))
+                        tr("Compiled against:") + "\n"+
+                        QString("libavformat-%1.%2.%3\n"
+                                "libavcodec-%4.%5.%6\n"
+                                "libavutil-%7.%8.%9")
                         .arg(LIBAVFORMAT_VERSION_MAJOR)
                         .arg(LIBAVFORMAT_VERSION_MINOR)
                         .arg(LIBAVFORMAT_VERSION_MICRO)
                         .arg(LIBAVCODEC_VERSION_MAJOR)
                         .arg(LIBAVCODEC_VERSION_MINOR)
-                        .arg(LIBAVCODEC_VERSION_MICRO)+"\n"+
+                        .arg(LIBAVCODEC_VERSION_MICRO)
+                        .arg(LIBAVUTIL_VERSION_MAJOR)
+                        .arg(LIBAVUTIL_VERSION_MINOR)
+                        .arg(LIBAVUTIL_VERSION_MICRO) +"\n"+
                         tr("Written by: Ilya Kotov <forkotov02@hotmail.ru>"));
 }
 
