@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QPixmap>
@@ -33,11 +33,9 @@ FLACMetaDataModel::FLACMetaDataModel(const QString &path, QObject *parent) : Met
 {
     if(path.startsWith("flac://"))
     {
-        QString p = QUrl(path).path();
-        p.replace(QString(QUrl::toPercentEncoding("#")), "#");
-        p.replace(QString(QUrl::toPercentEncoding("?")), "?");
-        p.replace(QString(QUrl::toPercentEncoding("%")), "%");
-        p.replace(QString(QUrl::toPercentEncoding(":")), ":");
+        QString p = path;
+        p.remove("flac://");
+        p.remove(QRegExp("#\\d+$"));
         m_path = p;
     }
     else
@@ -62,13 +60,13 @@ QHash<QString, QString> FLACMetaDataModel::audioProperties()
     qint64 size = 0;
     if(m_path.endsWith(".flac"))
     {
-        flacFile = new TagLib::FLAC::File(m_path.toLocal8Bit ());
+        flacFile = new TagLib::FLAC::File(m_path.toLocal8Bit().constData());
         taglib_ap = flacFile->audioProperties();
         size = flacFile->length();
     }
     else if(m_path.endsWith(".oga"))
     {
-        oggFlacFile = new TagLib::Ogg::FLAC::File(m_path.toLocal8Bit ());
+        oggFlacFile = new TagLib::Ogg::FLAC::File(m_path.toLocal8Bit().constData());
         taglib_ap = oggFlacFile->audioProperties();
         size = oggFlacFile->length();
     }
