@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2012 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2013 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -105,16 +105,17 @@ PlayList::PlayList (PlayListManager *manager, QWidget *parent)
              m_listWidget, SLOT(setModel(PlayListModel*)));
     m_listWidget->setModel(m_pl_manager->selectedPlayList());
 
+    createMenus();
+    createActions();
+    readSettings();
+
     m_titleBar = new PlayListTitleBar (this);
+    m_titleBar->setMinimumSize(0,0);
     m_titleBar->move (0,0);
     connect (m_pl_manager, SIGNAL (currentPlayListChanged(PlayListModel *, PlayListModel *)),
              m_titleBar, SLOT(setModel(PlayListModel*)));
     m_titleBar->setModel(m_pl_manager->currentPlayList());
 
-    createMenus();
-    createActions();
-
-    readSettings();
     setCursor(m_skin->getCursor(Skin::CUR_PNORMAL));
     updatePositions();
 #ifdef Q_WS_X11
@@ -176,8 +177,10 @@ void PlayList::createMenus()
     m_playlistMenu = new QMenu (this);
     m_copySelectedMenu = new QMenu (tr("&Copy Selection To"), m_listWidget->menu());
     m_copySelectedMenu->setIcon(QIcon::fromTheme("edit-copy"));
-    connect (m_copySelectedMenu, SIGNAL (aboutToShow ()  ), this, SLOT (generateCopySelectedMenu ()));
-    connect (m_copySelectedMenu, SIGNAL (triggered ( QAction *)  ), this, SLOT (copySelectedMenuActionTriggered( QAction *)));
+    connect(m_copySelectedMenu, SIGNAL(aboutToShow()),
+            SLOT(generateCopySelectedMenu()));
+    connect(m_copySelectedMenu, SIGNAL(triggered(QAction *)),
+            SLOT(copySelectedMenuActionTriggered(QAction *)));
 }
 
 void PlayList::createActions()
@@ -236,6 +239,10 @@ void PlayList::createActions()
     connect (trackAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
     signalMapper->setMapping (trackAct, PlayListModel::TRACK);
 
+    QAction* fileCreationDateAct = sort_mode_menu->addAction (tr("By File Creation Date"));
+    connect (fileCreationDateAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
+    signalMapper->setMapping (fileCreationDateAct, PlayListModel::FILE_CREATION_DATE);
+
     connect (signalMapper, SIGNAL (mapped (int)), m_pl_manager, SLOT (sort (int)));
 
     m_sortMenu->addMenu (sort_mode_menu);
@@ -275,6 +282,10 @@ void PlayList::createActions()
     connect (trackAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
     signalMapper->setMapping (trackAct, PlayListModel::TRACK);
 
+    fileCreationDateAct = sort_mode_menu->addAction (tr("By File Creation Date"));
+    connect (fileCreationDateAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
+    signalMapper->setMapping (fileCreationDateAct, PlayListModel::FILE_CREATION_DATE);
+
     connect (signalMapper, SIGNAL (mapped (int)), m_pl_manager, SLOT (sortSelection (int)));
 
     m_sortMenu->addMenu (sort_mode_menu);
@@ -379,6 +390,11 @@ void PlayList::mouseMoveEvent (QMouseEvent *e)
            sy--;
         resize (275+25*sx,116+29*sy);
 #else
+#ifdef Q_WS_X11
+        //avoid right corner moving during resize
+        if(layoutDirection() == Qt::RightToLeft)
+            WindowSystem::revertGravity(winId());
+#endif
         resize (e->x() +25, e->y() +25);
 #endif
     }
@@ -523,7 +539,15 @@ void PlayList::updateSkin()
 {
     setCursor(m_skin->getCursor(Skin::CUR_PNORMAL)); // TODO shaded
     m_resizeWidget->setCursor(m_skin->getCursor (Skin::CUR_PSIZE));
-    m_ratio = m_skin->ratio();
+    if(m_ratio != m_skin->ratio())
+    {
+        if(m_skin->ratio() < m_ratio)
+        {
+            setMinimumSize (275*m_skin->ratio(), (m_shaded ? 14 : 116)*m_skin->ratio());
+            resize(width()*m_skin->ratio() / m_ratio, height()*m_skin->ratio() / m_ratio);
+        }
+        m_ratio = m_skin->ratio();
+    }
     setMinimalMode(m_shaded);
 }
 
@@ -556,7 +580,7 @@ void PlayList::generateCopySelectedMenu()
     }
 }
 
-void PlayList::copySelectedMenuActionTriggered( QAction * action)
+void PlayList::copySelectedMenuActionTriggered(QAction *action)
 {
     PlayListModel *targetPlayList = 0;
     QString actionText=action->text();
@@ -608,7 +632,6 @@ void PlayList::setMinimalMode(bool b)
         setMinimumSize(275*m_ratio, 116*m_ratio);
         resize (width(), m_height);
         setSizeIncrement (25*m_ratio, 29*m_ratio);
-
     }
     updatePositions();
     update();
