@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2012 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2013 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -25,10 +25,11 @@
 #include "effect.h"
 #include "buffer.h"
 #include "decoder.h"
-#include "output.h"
+#include "outputwriter_p.h"
 #include "decoderfactory.h"
 #include "effectfactory.h"
 #include "inputsource.h"
+#include "statehandler.h"
 #include "audioconverter_p.h"
 #include "qmmpaudioengine_p.h"
 #include "metadatamanager.h"
@@ -238,7 +239,8 @@ void QmmpAudioEngine::stop()
     if (m_output)
         m_output->recycler()->cond()->wakeAll();
 
-    wait();
+    if(isRunning())
+        wait();
 
     if (m_output)
     {
@@ -250,8 +252,11 @@ void QmmpAudioEngine::stop()
     // wake up threads
     if (m_output)
     {
+        m_output->mutex()->lock();
         m_output->recycler()->cond()->wakeAll();
-        m_output->wait();
+        m_output->mutex()->unlock();
+        if(m_output->isRunning())
+            m_output->wait();
         delete m_output;
         m_output = 0;
     }
@@ -309,8 +314,6 @@ void QmmpAudioEngine::updateReplayGainSettings()
 
 void QmmpAudioEngine::run()
 {
-    Q_ASSERT(m_chan == 0);
-    Q_ASSERT(!m_output_buf);
     mutex()->lock ();
     m_next = false;
     qint64 len = 0;
@@ -452,7 +455,12 @@ void QmmpAudioEngine::run()
     m_next = false;
     if (m_finish)
         finish();
-    m_output->recycler()->cond()->wakeAll();
+    if(m_output)
+    {
+        m_output->mutex()->lock();
+        m_output->recycler()->cond()->wakeAll();
+        m_output->mutex()->unlock();
+    }
     mutex()->unlock();
 }
 
@@ -521,24 +529,34 @@ void QmmpAudioEngine::sendMetaData()
     }
 }
 
-Output *QmmpAudioEngine::createOutput()
+OutputWriter *QmmpAudioEngine::createOutput()
 {
-    Output *output = Output::create(0);
-    if(!output)
+    OutputWriter *output = new OutputWriter(this);
+    if (!output->initialize(m_ap.sampleRate(), m_ap.channels(), m_ap.format()))
     {
-        qWarning("QmmpAudioEngine: unable to create output");
+        delete output;
         StateHandler::instance()->dispatch(Qmmp::FatalError);
         return 0;
     }
-    if (!output->initialize(m_ap.sampleRate(), m_ap.channels(), m_ap.format()) ||
-            output->audioParameters() != m_ap) //TODO add soundconverter
+    if(output->audioParameters() != m_ap)
     {
-        qWarning("QmmpAudioEngine: unable to initialize output");
-        delete output;
-        output = 0;
-        StateHandler::instance()->dispatch(Qmmp::FatalError);
-        return false;
+        if(output->audioParameters().format() == Qmmp::PCM_S16LE) //output supports 16 bit only
+        {
+            Effect *effect = new AudioConverter();
+            effect->configure(m_ap.sampleRate(), m_ap.channels(), m_ap.format());
+            m_ap = effect->audioParameters();
+            m_effects.append(effect);
+            qDebug("QmmpAudioEngine: output plugin requires 16 bit, using 16-bit converter");
+        }
+        else
+        {
+            qWarning("QmmpAudioEngine: unsupported audio format");
+            delete output;
+            StateHandler::instance()->dispatch(Qmmp::FatalError);
+            return 0;
+        }
     }
+
     if(m_output_buf)
         delete [] m_output_buf;
     m_bks = QMMP_BLOCK_FRAMES * m_ap.channels() * m_ap.sampleSize();
@@ -560,7 +578,7 @@ void QmmpAudioEngine::prepareEffects(Decoder *d)
             delete e;
         }
     }
-    QList <Effect *> m_tmp_effects = m_effects;
+    QList <Effect *> tmp_effects = m_effects;
     m_effects.clear();
 
     if(m_settings->use16BitOutput())
@@ -576,7 +594,7 @@ void QmmpAudioEngine::prepareEffects(Decoder *d)
             continue;
 
         Effect *effect = 0;
-        foreach(Effect *e, m_tmp_effects) //find effect
+        foreach(Effect *e, tmp_effects) //find effect
         {
             if(e->factory() == factory)
                 effect = e;
@@ -586,7 +604,7 @@ void QmmpAudioEngine::prepareEffects(Decoder *d)
                       m_blockedEffects.contains(effect))) //destroy effect which require restart
         {
             m_blockedEffects.removeAll(effect);
-            m_tmp_effects.removeAll(effect);
+            tmp_effects.removeAll(effect);
             delete effect;
             effect = 0;
         }
@@ -601,7 +619,7 @@ void QmmpAudioEngine::prepareEffects(Decoder *d)
             }
         }
         m_effects << effect;
-        m_tmp_effects.removeAll(effect);
+        tmp_effects.removeAll(effect);
     }
     m_chan = m_ap.channels();
 }
