@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,13 +15,15 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 #ifndef SOUNDCORE_H
 #define SOUNDCORE_H
 
 #include <QObject>
 #include <QString>
+#include <QQueue>
+#include <QHash>
 #include "decoder.h"
 #include "output.h"
 #include "visual.h"
@@ -62,7 +64,6 @@ public:
      * Chages equalizer settings to \b settings.
      */
     void setEqSettings(const EqSettings &settings);
-
     /*!
      * Returns left volume level.
      */
@@ -86,7 +87,7 @@ public:
     /*!
      * Returns sample size (in bits).
      */
-    int precision();
+    int sampleSize();
     /*!
      * Returns channels number.
      */
@@ -98,11 +99,15 @@ public:
     /*!
      * Returns all meta data in map.
      */
-    QMap <Qmmp::MetaData, QString> metaData();
+    QMap <Qmmp::MetaData, QString> metaData() const;
     /*!
      * Returns the metdata string associated with the given \b key.
      */
-    QString metaData(Qmmp::MetaData key);
+    QString metaData(Qmmp::MetaData key) const;
+    /*!
+     * Returns a hash of stream information if available
+     */
+    QHash<QString, QString> streamInfo() const;
     /*!
      * Returns a pointer to the SoundCore instance.
      */
@@ -136,7 +141,12 @@ public slots:
     /*!
      *  This function returns file path or stream url.
      */
-    const QString url();
+    const QString url() const;
+    /*!
+     *  Indicates that the current active engine will be used for the next queued track.
+     *  May be useful for some effect plugins.
+     */
+    bool nextTrackAccepted() const;
 
 signals:
     /*!
@@ -161,9 +171,9 @@ signals:
     void frequencyChanged(quint32 frequency);
     /*!
      * Emitted when sample size has changed.
-     * @param precision New sample size (in bits)
+     * @param size New sample size (in bits)
      */
-    void precisionChanged(int precision);
+    void sampleSizeChanged(int size);
     /*!
      * Emitted when channels number has changed.
      * @param channels New channels number.
@@ -173,6 +183,10 @@ signals:
      * Emitted when new metadata is available.
      */
     void metaDataChanged ();
+    /*!
+     * Emitted when new stream information is available.
+     */
+    void streamInfoChanged();
     /*!
      * This signal is emitted when the state of the SoundCore has changed.
      */
@@ -197,22 +211,30 @@ signals:
     void nextTrackRequest();
 
 private slots:
-    bool enqueue();
-    void startPendingEngine();
-    void updateVolume();
+    void startNextSource();
+    void startNextEngine();
 
 private:
+    bool event(QEvent *e);
+    enum NextEngineState
+    {
+        NO_ENGINE = 0,
+        SAME_ENGINE,
+        ANOTHER_ENGINE,
+        INVALID_SOURCE
+    };
+    QMap <Qmmp::MetaData, QString> m_metaData;
+    QHash <QString, QString> m_streamInfo;
     Decoder* m_decoder;
     QString m_url;
-    bool m_error;
     QList <Visual*> m_visuals;
     QWidget *m_parentWidget;
     static SoundCore* m_instance;
     StateHandler *m_handler;
     VolumeControl *m_volumeControl;
     AbstractEngine *m_engine;
-    AbstractEngine *m_pendingEngine;
-    QList<InputSource *> m_pendingSources;
+    QQueue<InputSource *> m_sources;
+    int m_nextState;
 };
 
 #endif
