@@ -28,6 +28,7 @@
 #include <QTimer>
 #include <QBuffer>
 #include <QMetaType>
+#include <QDateTime>
 #include <time.h>
 #include <qmmp/metadatamanager.h>
 #include "playlistparser.h"
@@ -70,7 +71,7 @@ PlayListModel::PlayListModel(const QString &name, QObject *parent)
     m_shuffle = 0;
     m_total_length = 0;
     m_current = 0;
-    is_repeatable_list = false;
+    m_is_repeatable_list = false;
     m_stop_item = 0;
     m_play_state = new NormalPlayState(this);
     m_loader = new FileLoader(this);
@@ -82,6 +83,7 @@ PlayListModel::PlayListModel(const QString &name, QObject *parent)
 
 PlayListModel::~PlayListModel()
 {
+    blockSignals(true);
     clear();
     delete m_play_state;
     m_loader->finish();
@@ -112,6 +114,7 @@ void PlayListModel::add(PlayListItem *item)
 
     emit itemAdded(item);
     emit listChanged();
+    emit countChanged();
 }
 
 void PlayListModel::add(QList <PlayListItem *> items)
@@ -129,6 +132,7 @@ void PlayListModel::add(QList <PlayListItem *> items)
         emit itemAdded(item);
     }
     emit listChanged();
+    emit countChanged();
 }
 
 void PlayListModel::add(const QString &path)
@@ -176,22 +180,27 @@ PlayListItem* PlayListModel::nextItem()
     return m_items.at(index);
 }
 
-PlayListItem* PlayListModel::item(int row) const
+int PlayListModel::indexOf(PlayListItem* item) const
 {
-    return (row <  m_items.size() && row >= 0) ? m_items.at(row) : 0;
+    return m_items.indexOf(item);
 }
 
-int PlayListModel::currentRow()
+PlayListItem* PlayListModel::item(int index) const
+{
+    return (index <  m_items.size() && index >= 0) ? m_items.at(index) : 0;
+}
+
+int PlayListModel::currentIndex()
 {
     return m_current;
 }
 
-bool PlayListModel::setCurrent(int c)
+bool PlayListModel::setCurrent(int index)
 {
-    if (c > count()-1 || c < 0)
+    if (index > count()-1 || index < 0)
         return false;
-    m_current = c;
-    m_currentItem = m_items.at(c);
+    m_current = index;
+    m_currentItem = m_items.at(index);
     emit currentChanged();
     emit listChanged();
     return true;
@@ -253,6 +262,7 @@ void PlayListModel::clear()
     m_total_length = 0;
     m_play_state->resetState();
     emit listChanged();
+    emit countChanged();
 }
 
 void PlayListModel::clearSelection()
@@ -291,10 +301,10 @@ QStringList PlayListModel::getTimes(int b,int l)
     return m_times;
 }
 
-bool PlayListModel::isSelected(int row)
+bool PlayListModel::isSelected(int index)
 {
-    if (m_items.count() > row && row >= 0)
-        return m_items.at(row)->isSelected();
+    if (m_items.count() > index && index >= 0)
+        return m_items.at(index)->isSelected();
 
     return false;
 }
@@ -309,11 +319,11 @@ bool PlayListModel::contains(const QString &url)
     return false;
 }
 
-void PlayListModel::setSelected(int row, bool selected)
+void PlayListModel::setSelected(int index, bool selected)
 {
-    if (m_items.count() > row && row >= 0)
+    if (m_items.count() > index && index >= 0)
     {
-        m_items.at(row)->setSelected(selected);
+        m_items.at(index)->setSelected(selected);
         emit listChanged();
     }
 }
@@ -355,6 +365,7 @@ void PlayListModel::removeAt (int i)
 
         m_play_state->prepare();
         emit listChanged();
+        emit countChanged();
     }
 }
 
@@ -410,6 +421,7 @@ void PlayListModel::removeSelection(bool inverted)
     m_play_state->prepare();
 
     emit listChanged();
+    emit countChanged();
 }
 
 void PlayListModel::invertSelection()
@@ -468,7 +480,7 @@ void PlayListModel::moveItems(int from, int to)
     if (from == to)
         return;
 
-    QList<int> selected_rows = selectedRows();
+    QList<int> selected_rows = selectedIndexes();
 
     if (!(bottommostInSelection(from) == INVALID_ROW ||
             from == INVALID_ROW ||
@@ -529,11 +541,11 @@ const SimpleSelection& PlayListModel::getSelection(int row)
     m_selection.m_top = topmostInSelection(row);
     m_selection.m_anchor = row;
     m_selection.m_bottom = bottommostInSelection(row);
-    m_selection.m_selected_rows = selectedRows();
+    m_selection.m_selected_indexes = selectedIndexes();
     return m_selection;
 }
 
-QList<int> PlayListModel::selectedRows() const
+QList<int> PlayListModel::selectedIndexes() const
 {
     QList<int>selected_rows;
     for (int i = 0;i<m_items.count();i++)
@@ -583,7 +595,7 @@ bool PlayListModel::isQueued(PlayListItem* f) const
 
 void PlayListModel::setCurrentToQueued()
 {
-    setCurrent(row(m_queued_songs.dequeue()));
+    setCurrent(indexOf(m_queued_songs.dequeue()));
 }
 
 bool PlayListModel::isEmptyQueue() const
@@ -714,7 +726,26 @@ static bool _trackGreaterComparator(PlayListItem* s1,PlayListItem* s2)
 {
     return s1->value(Qmmp::TRACK).toInt() > s2->value(Qmmp::TRACK).toInt();
 }
+//by file creation date
+static bool _fileCreationDateLessComparator(PlayListItem* s1,PlayListItem* s2)
+{
+    return QFileInfo(s1->value(Qmmp::URL)).created() < QFileInfo(s2->value(Qmmp::URL)).created();
+}
 
+static bool _fileCreationDateGreaterComparator(PlayListItem* s1,PlayListItem* s2)
+{
+    return QFileInfo(s1->value(Qmmp::URL)).created() > QFileInfo(s2->value(Qmmp::URL)).created();
+}
+//by file modification date
+static bool _fileModificationDateLessComparator(PlayListItem* s1,PlayListItem* s2)
+{
+    return QFileInfo(s1->value(Qmmp::URL)).lastModified() < QFileInfo(s2->value(Qmmp::URL)).lastModified();
+}
+
+static bool _fileModificationDateGreaterComparator(PlayListItem* s1,PlayListItem* s2)
+{
+    return QFileInfo(s1->value(Qmmp::URL)).lastModified() > QFileInfo(s2->value(Qmmp::URL)).lastModified();
+}
 // This is main sort method
 void PlayListModel::doSort(int sort_mode,QList<PlayListItem*>& list_to_sort)
 {
@@ -762,6 +793,14 @@ void PlayListModel::doSort(int sort_mode,QList<PlayListItem*>& list_to_sort)
         compareLessFunc = _trackLessComparator;
         compareGreaterFunc = _trackGreaterComparator;
         break;
+    case FILE_CREATION_DATE:
+        compareLessFunc = _fileCreationDateLessComparator;
+        compareGreaterFunc = _fileCreationDateGreaterComparator;
+        break;
+    case FILE_MODIFICATION_DATE:
+        compareLessFunc = _fileModificationDateLessComparator;
+        compareGreaterFunc = _fileModificationDateGreaterComparator;
+        break;
     default:
         compareLessFunc = _titleLessComparator;
         compareGreaterFunc = _titleGreaterComparator;
@@ -785,7 +824,7 @@ void PlayListModel::doSort(int sort_mode,QList<PlayListItem*>& list_to_sort)
 void PlayListModel::sortSelection(int mode)
 {
     QList<PlayListItem*>selected_items = selectedItems();
-    QList<int>selected_rows = selectedRows();
+    QList<int>selected_rows = selectedIndexes();
 
     doSort(mode,selected_items);
 
@@ -819,7 +858,7 @@ void PlayListModel::prepareForShufflePlaying(bool val)
 
 void PlayListModel::prepareForRepeatablePlaying(bool val)
 {
-    is_repeatable_list = val;
+    m_is_repeatable_list = val;
 }
 
 void PlayListModel::doCurrentVisibleRequest()
@@ -830,12 +869,9 @@ void PlayListModel::doCurrentVisibleRequest()
 
 void PlayListModel::loadPlaylist(const QString &f_name)
 {
-    PlaylistFormat* prs = PlaylistParser::instance()->findByPath(f_name);
-    if(!prs)
-    {
-        //qWarning("PlayListModel: unsupported playlist format");
+    PlayListFormat* prs = PlayListParser::findByPath(f_name);
+    if(!prs || !QFile::exists(f_name))
         return;
-    }
 
     QFile file(f_name);
     if (!file.open(QIODevice::ReadOnly))
@@ -864,7 +900,7 @@ void PlayListModel::loadPlaylist(const QString &f_name)
 
 void PlayListModel::savePlaylist(const QString & f_name)
 {
-    PlaylistFormat* prs = PlaylistParser::instance()->findByPath(f_name);
+    PlayListFormat* prs = PlayListParser::findByPath(f_name);
     if (prs)
     {
         QFile file(f_name);
@@ -884,7 +920,7 @@ void PlayListModel::savePlaylist(const QString & f_name)
 
 bool PlayListModel::isRepeatableList() const
 {
-    return is_repeatable_list;
+    return m_is_repeatable_list;
 }
 
 bool PlayListModel::isShuffle() const
